FieldStyle class

字段样式配置

Constructors

FieldStyle({double? fontSize, PdfColor? color, bool bold = false, Alignment? alignment, PdfColor? backgroundColor})

Properties

alignment Alignment?
文本对齐方式
final
backgroundColor PdfColor?
背景颜色
final
bold bool
是否粗体
final
color PdfColor?
字体颜色
final
fontSize double?
字体大小
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited