FooterModule class

页脚模块,用于显示页面底部信息

Inheritance

Constructors

FooterModule({FooterConfig? config, required ModuleDescriptor descriptor})

Properties

config BaseModuleConfig
模块配置
finalinherited
descriptor ModuleDescriptor
模块描述符
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canRender(ModuleDescriptor descriptor) bool
检查是否可以渲染该数据
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(ModuleDescriptor descriptor, PDFContext context) Future<List<Widget>>
渲染模块内容
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited