LayoutConstants class
页面布局常量
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultFontSize → const double
- 默认字体大小
- defaultMargin → const double
- 默认页边距
- defaultModuleSpacing → const double
- 默认模块间距
- largeFontSize → const double
- 大字体大小
- largeTitleFontSize → const double
- 大标题字体大小
- smallFontSize → const double
- 小字体大小
- titleFontSize → const double
- 标题字体大小