ModuleDescriptor class
模块描述符
描述一个完整的模块配置,包含模块类型、模块ID和数据源
- Implementers
Constructors
- ModuleDescriptor(ModuleType type, String moduleId, dynamic data)
-
const
- ModuleDescriptor.withDefaultId(ModuleType type, {dynamic data})
-
创建带有默认 moduleId 的模块描述符
factory
Properties
- data → dynamic
-
数据源
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- moduleId → String
-
模块ID(用于区分同一类型的不同实例)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ModuleType
-
模块类型
final
Methods
-
copyWith(
{ModuleType? type, String? moduleId, dynamic data}) → ModuleDescriptor - 复制并修改模块描述符
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- approval → const ModuleDescriptor
- logo → const ModuleDescriptor
- 预定义的模块描述符(六个默认模块)
- mainTable → const ModuleDescriptor
- subTable → const ModuleDescriptor
- title → const ModuleDescriptor